@@ -51,12 +51,16 @@ class Main(QMainWindow):
         self.connect(self.actions['history'], SIGNAL('triggered()'), self.pickHistoryFile);
         self.connect(self.actions['newGame'], SIGNAL('triggered()'), self.table.newGame);
 
-    def gameOver(self, won = False):
-        if  won: message = 'Game Over. You Won!'
-        else: message = 'Game Over. You Lost!'
+    def gameOver(self, scores):
+        if scores[0] > scores[1]: status = 'You Won'
+        elif scores[0] < scores[1]: status = 'You Lost'
+        else: status = 'It\'s a tie'
         msgBox = QMessageBox()
-        msgBox.setText(message)
-        msgBox.exec_()
+        msgBox.setText('Game Over. %s!' % status)
+        #msgBox.setStandardButtons(QMessageBox.Yes | QMessageBox.No);
+        ret = msgBox.exec_()
+        if ret == QMessageBox.Yes:
+            self.table.newGame()
 
     def pickHistoryFile(self):
         dialog = QFileDialog(self)
